==> javie-0.3.4-src.tar.gz: javie-0.3.4-src/ch.kuramo.javie.api/src/main/java/ch/kuramo/javie/api/services/IVideoEffectContext.java <==
/*
 * Copyright (c) 2009,2010 Yoshikazu Kuramochi
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package ch.kuramo.javie.api.services;

import javax.media.opengl.GL;
import javax.media.opengl.glu.GLU;

import ch.kuramo.javie.api.ColorMode;
import ch.kuramo.javie.api.IVideoBuffer;
import ch.kuramo.javie.api.RenderResolution;
import ch.kuramo.javie.api.VideoBounds;

public interface IVideoEffectContext extends IEffectContext {

	GL getGL();

	GLU getGLU();

	RenderResolution getRenderResolution();

	ColorMode getColorMode();


	IVideoBuffer createVideoBuffer(VideoBounds bounds);

	VideoBounds getPreviousBounds();

	IVideoBuffer doPreviousEffect();

}

==> javie-0.3.13-src.tar.gz: javie-0.3.13-src/ch.kuramo.javie.api/src/main/java/ch/kuramo/javie/api/services/IVideoEffectContext.java <==
/*
 * Copyright (c) 2009,2010 Yoshikazu Kuramochi
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package ch.kuramo.javie.api.services;

import ch.kuramo.javie.api.ICamera;
import ch.kuramo.javie.api.IVideoBuffer;
import ch.kuramo.javie.api.VideoBounds;

/**
 * ビデオエフェクト用のエフェクトコンテキストです。
 */
public interface IVideoEffectContext extends IEffectContext {

	/**
	 * ひとつ前のビデオエフェクトまで処理を実行した場合に得られるビデオデータの位置とサイズを返します。
	 * 
	 * @return ひとつ前のビデオエフェクトまで処理を実行した場合に得られるビデオデータの位置とサイズ
	 */
	VideoBounds getPreviousBounds();

	/**
	 * ひとつ前のビデオエフェクトまで処理を実行します。
	 * 
	 * @return ひとつ前のビデオエフェクトまで処理を実行した結果のビデオデータ
	 */
	IVideoBuffer doPreviousEffect();

	/**
	 * コンポジションカメラ (現在時刻における、コンポジションのアクティブなカメラ) を取得します。
	 * 
	 * @return コンポジションカメラを表す <code>ICamera</code> オブジェクト
	 */
	ICamera getCamera();

}
